@@ -147,7 +147,7 @@ class EsHelper:
     async def es_search(self, route_key, body):
         path = f"/{route_key}/_search"
         url = self.pool.format_url(path)
-        res = self.pool.format_es_post(url, body=body)
+        res = self.pool.format_es_request(url, methd="post", body=body)
         return res
 
     def sync_send_es_post(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10,
@@ -448,13 +448,13 @@ class EsHelper:
         for k, v in new_data.items():
             source += f'ctx._source.{k}={v};'
         data["script"]["source"] = source
-        res = self.pool.format_es_post(url=url, body=data)
+        res = self.pool.format_es_request(url=url, methd="post", body=data)
         return res
 
     def sync_update_one(self, route_key, id, data, doc_type="_doc"):
         path = f"/{route_key}/{doc_type}/{id}/_update"
         url = self.pool.format_url(path)
-        res = self.pool.format_es_post(url, body=data)
+        res = self.pool.format_es_request(url, methd="post", body=data)
         return res
 
     def sync_insert_one(self, route_key, data, id=None, doc_type="_doc"):
@@ -463,20 +463,20 @@ class EsHelper:
         else:
             path = f"/{route_key}/{doc_type}"
         url = self.pool.format_url(path)
-        res = self.pool.format_es_post(url, body=data)
+        res = self.pool.format_es_request(url, methd="post", body=data)
         return res
 
     def sync_insert_data(self, route_key, data, doc_type="_doc"):
         path = f"/{route_key}/{doc_type}/_bulk"
         url = self.pool.format_url(path)
-        res = self.pool.format_es_post(url, body=data)
+        res = self.pool.format_es_request(url, methd="post", body=data)
         return res
 
     def sync_es_search(self, route_key, body):
         path = f"/{route_key}/_search"
         url = self.pool.format_url(path)
         self.correction_body(route_key, body)
-        res = self.pool.format_es_post(url, body=body)
+        res = self.pool.format_es_request(url, methd="post", body=body)
         if "error" in res:
             raise Exception(f"res={res}")
         return res
@@ -517,7 +517,7 @@ class EsHelper:
         path = f"/{route_key}/_search?scroll={scroll}"
         url = self.pool.format_url(path)
         self.correction_body(route_key, body)
-        res = self.pool.format_es_post(url, body=body)
+        res = self.pool.format_es_request(url, methd="post", body=body)
         data_list = []
         if "error" in res:
             raise Exception(f"res={res}")
@@ -528,7 +528,7 @@ class EsHelper:
         scroll_path = f"/_search/scroll"
         scroll_url = self.pool.format_url(scroll_path)
         while scroll_id:
-            res = self.pool.format_es_post(scroll_url, body={'scroll': scroll, 'scroll_id': scroll_id})
+            res = self.pool.format_es_request(scroll_url, methd="post", body={'scroll': scroll, 'scroll_id': scroll_id})
             if "error" in res:
                 raise Exception(f"res={res}")
             hits = res.get("hits", {}).get("hits", [])
@@ -550,7 +550,7 @@ class EsHelper:
         if field:
             path = f"{path}/field/{field}"
         url = self.pool.format_url(path)
-        res = self.pool.format_es_get(url)
+        res = self.pool.format_es_request(url, methd="get")
         return res
 
     def sync_es_request(self, path, method, params=None, body=None):
@@ -559,13 +559,13 @@ class EsHelper:
         if method in ["get", "post", "put", "delete"]:
             res = None
             if method == "get":
-                res = self.pool.format_es_get(url=url, params=params)
+                res = self.pool.format_es_request(url=url, methd="get", params=params)
             elif method == "post":
-                res = self.pool.format_es_post(url=url, body=body, params=params)
+                res = self.pool.format_es_request(url=url, methd="post", body=body, params=params)
             elif method == "put":
-                res = self.pool.format_es_put(url=url, body=body, params=params)
+                res = self.pool.format_es_request(url=url, methd="put", body=body, params=params)
             elif method == "delete":
-                res = self.pool.format_es_delete(url=url, params=params)
+                res = self.pool.format_es_request(url=url, methd="delete", params=params)
             return res
         else:
             raise Exception(f"method={method} is not supported")
