@@ -6,7 +6,6 @@ import traceback
 from tornado.options import options
 
 from lesscode.db.page import Page
-from lesscode.utils.encryption_algorithm import AES
 
 
 class Neo4jHelper:
@@ -1006,8 +1005,12 @@ def parse_relation_item_more_relation(item, id_key, name_key):
 
 
 def parse_node_dict(node, id_key, name_key):
+    try:
+        encryption_algorithm = importlib.import_module("lesscode_utils.encryption_algorithm")
+    except ImportError:
+        raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
     return {
-        "id": AES.encrypt(options.aes_key, node._properties[id_key]),
+        "id": encryption_algorithm.AES.encrypt(key=options.aes_key, text=node._properties[id_key]),
         "name": node._properties[name_key],
         "label": list(node._labels)[0]
     }
