@@ -6,12 +6,6 @@ import traceback
 
 from tornado.options import options
 
-kafka = None
-try:
-    kafka = importlib.import_module("kafka")
-except ImportError as e:
-    raise Exception(f"kafka is not exist,run:pip install kafka-python==2.0.2")
-
 
 class KafkaHelper:
     def __init__(self, **kwargs):
@@ -40,9 +34,17 @@ class KafkaHelper:
                 "sasl_plain_username": username,
                 "sasl_plain_password": password
             }
+        try:
+            kafka = importlib.import_module("kafka")
+        except ImportError:
+            raise Exception(f"kafka is not exist,run:pip install kafka-python==2.0.2")
         self.api_version = tuple([int(x) for x in kafka.__version__.split(".")])
 
     def publish(self, value=None, key=None, headers=None, partition=None, timestamp_ms=None, **configs):
+        try:
+            kafka = importlib.import_module("kafka")
+        except ImportError as e:
+            raise Exception(f"kafka is not exist,run:pip install kafka-python==2.0.2")
         producer = kafka.KafkaProducer(bootstrap_servers=self.bootstrap_servers,
                                        api_version=self.api_version,
                                        **self.sasl_config,
@@ -65,6 +67,10 @@ class KafkaHelper:
             logging.error(traceback.format_exc())
 
     def consume(self, callback, **configs):
+        try:
+            kafka = importlib.import_module("kafka")
+        except ImportError as e:
+            raise Exception(f"kafka is not exist,run:pip install kafka-python==2.0.2")
         consumer = kafka.KafkaConsumer(self.topic, bootstrap_servers=self.bootstrap_servers,
                                        api_version=self.api_version,
                                        enable_auto_commit=False,
