@@ -94,9 +94,9 @@ def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn
             value = json.loads(data)
             return value
         else:
-            logging.info("str_select_key为".format(cache_key))
+            logging.info("str_select_key为{}".format(cache_key))
             return False
-    if options.common_cache_enable:
+    if options.global_cache_enable:
         ttl = RedisHelper(conn_name).get_connection(sync=True).ttl(cache_key)
 
         if ttl and ex >= 900 and 0 < ttl <= ex - 900:
@@ -112,7 +112,7 @@ def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn
             value = json.loads(data)
             return value
         else:
-            logging.info("str_select_key为".format(cache_key))
+            logging.info("str_select_key为{}".format(cache_key))
             return False
     return False
 
@@ -152,7 +152,7 @@ def insert_cache(data, ex, cache_key, conn_name=None):
                 RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
             except:
                 logging.error(traceback.format_exc())
-        if options.common_cache_enable:
+        if options.global_cache_enable:
             try:
                 RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
             except:
