@@ -8,6 +8,14 @@ from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
 
 
+def get_basic_auth(username, password):
+    try:
+        httpx = importlib.import_module("httpx")
+    except ImportError as e:
+        raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+    return httpx.BasicAuth(username, password)
+
+
 async def common_request(method, path, params=None, data=None, json=None, base_url=options.data_server,
                          result_type="json", pack=False, connect_config=None, **kwargs):
     try:
@@ -23,7 +31,7 @@ async def common_request(method, path, params=None, data=None, json=None, base_u
     else:
         kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
     if not connect_config or not isinstance(connect_config, dict):
-        connect_config = dict()
+        connect_config = {"timeout": None}
     with httpx.AsyncClient(**connect_config) as session:
         async with session.request(method.upper(), url=base_url + path, params=params, json=json, data=data,
                                    **kwargs) as resp:
@@ -37,8 +45,10 @@ async def common_request(method, path, params=None, data=None, json=None, base_u
                         raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
             elif result_type == "text":
                 result = await resp.text
+            elif result_type == "origin":
+                return resp
             else:
-                result = await resp.content.read()
+                result = await resp.content
             return result
 
 
@@ -89,7 +99,7 @@ def sync_common_request(method, path, params=None, data=None, json=None, base_ur
     else:
         kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
     if not connect_config or not isinstance(connect_config, dict):
-        connect_config = dict()
+        connect_config = {"timeout": None}
     with httpx.Client(**connect_config) as session:
         try:
             res = session.request(method.upper(), url=base_url + path, params=params, data=data, json=json, **kwargs)
@@ -103,6 +113,8 @@ def sync_common_request(method, path, params=None, data=None, json=None, base_ur
                         raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
             elif result_type == "text":
                 res = res.text
+            elif result_type == "origin":
+                return res
             else:
                 res = res.content
             return res
